#!/usr/bin/env python
# -*- coding: utf-8 -*-

# Inspire by a Esper tutorial found here:  http://gimpchat.com/viewtopic.php?f=23&t=7973#p103313

# author: Pocholo
# date: 9/10/21

# Comments directed to http://gimpchat.com

# Installation:
# This script should be placed in the user plugin folder

# Copyright (C)

#   This program is free software: you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by   
#   the Free Software Foundation, either version 3 of the License, or
#   (at your option) any later version.

#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public License
#   along with this program.  If not, see <https://www.gnu.org/licenses/>.


from gimpfu import *
import gettext
import os, sys,time 

gettext.install("gimp20", gimp.locale_directory, unicode=True)

def pm_blinds_text_effect(customtext, fontname, color):

	#Initiates the defaults
    pdb.gimp_context_set_defaults()
    
    #Create the background
    img = pdb.gimp_image_new(1200, 700, RGB)
    backLayer = pdb.gimp_layer_new(img, img.width, img.height, RGBA_IMAGE, "Background", 100, LAYER_MODE_NORMAL)
    pdb.gimp_image_add_layer(img, backLayer, 0)
    pdb.gimp_context_set_foreground("Black")
    pdb.gimp_drawable_fill(backLayer, FILL_FOREGROUND)
        
    #Create the text		
    size = 300
    textW = size/0.3
    textH = size/0.9
    pdb.gimp_context_set_foreground(color)
    textLayer = pdb.gimp_text_layer_new(img, customtext, fontname, size, PIXELS)
    pdb.gimp_image_add_layer(img, textLayer, 0)
    pdb.gimp_layer_add_alpha(textLayer)
    pdb.gimp_text_layer_set_justification(textLayer, 2)
    pdb.gimp_text_layer_set_letter_spacing(textLayer, 20)
    	
	#Resize text
    pdb.gimp_layer_scale (textLayer, textW, textH, TRUE)
			
	#Making the text centered	
    textLayer = pdb.gimp_image_get_active_layer(img)
    pdb.gimp_image_set_active_layer(img, textLayer)
    wh = pdb.gimp_drawable_width(textLayer)
    hh = pdb.gimp_drawable_height(textLayer)
    w = pdb.gimp_image_width(img)
    h = pdb.gimp_image_height(img)
    pdb.gimp_image_set_active_layer(img,textLayer)
    centerx=w/2
    centery=h/2
    adw=wh/2
    adh=hh/2
    sw=centerx - adw
    sh=centery - adh		
    pdb.gimp_layer_set_offsets(textLayer, sw, sh)
    pdb.gimp_layer_resize_to_image_size(textLayer)
    pdb.gimp_layer_set_mode(textLayer, LAYER_MODE_NORMAL)
    pdb.gimp_layer_set_opacity(textLayer, 100)  
    #Rename the text layer
    pdb.gimp_item_set_name(textLayer, "Text")
    
    #Process
    pdb.gimp_display_new(img)
       
	#Create the blids using the grid plugin
    layer = pdb.gimp_layer_new(img, img.width, img.height, RGBA_IMAGE, "Layer", 100, LAYER_MODE_NORMAL)
    pdb.gimp_image_add_layer(img, layer, 0)
    pdb.gimp_drawable_fill(layer, FILL_TRANSPARENT)
    pdb.plug_in_grid(img, layer, 
                              7,   #hwidth 
                             20,   #hspace 
                              5,   #hoffset 
                      (0, 0, 0),   #hcolor 
                            255,   #hopacity 
                              0,   #vwidth 
                              1,   #vspace 
                              0,   #voffset 
                      (0, 0, 0),   #vcolor 
                            255,   #vopacity 
                              0,   #iwidth 
                              0,   #ispace 
                              0,   #ioffset
                      (0, 0, 0),   #icolor 
                           255)    #iopacity
	
    pdb.gimp_image_select_item(img, 2, layer)                            
    pdb.gimp_edit_clear(textLayer)
    pdb.gimp_selection_none(img)
    pdb.gimp_image_remove_layer(img, layer)
    
    #Bevel and emboss
    pdb.python_layerfx_bevel_emboss(img, textLayer, 
												 1,   #style inner bevel
											    65,   #depth 
												 0,   #direction 
												 3,   #size 
												 3,   #soften
												90,   #angle 
												35,   #altitude 
												 0,   #gloss_contour - linear 
										   "White",   #highlight_color 
												 4,   #highlight_mode - screen
											   100,   #highlight_opacity
										   "Black",   #shadow_color 
												 3,   #shadow_mode - multyply
											   100,   #shadow_opacity 
												 0,   #surface_contour - linear 
											 FALSE,   #use_texture 
										"3D Green",   #pattern 
											   100,   #scale 
											   100,   #tex_depth 
											  TRUE,   #invert 
											  True)   #merge
    
    #Make a text copy
    textLayer = pdb.gimp_image_get_layer_by_name(img, "Text")
    copyLayer = pdb.gimp_edit_copy(textLayer)
    copyLayer = pdb.gimp_layer_new(img, img.width, img.height, RGBA_IMAGE, "Copy", 100, LAYER_MODE_NORMAL)
    pdb.gimp_image_add_layer(img, copyLayer, 0)
    pdb.gimp_drawable_fill(copyLayer, FILL_TRANSPARENT)
    floating_sel = pdb.gimp_edit_paste(copyLayer, FALSE)
    pdb.gimp_floating_sel_anchor(floating_sel)
    copyLayer = pdb.gimp_image_get_layer_by_name(img, "Copy")
    
    #Create the effect
    pdb.plug_in_mblur_inward(img, textLayer, 
                                          2,  #type - zoom
                                         30,  #length
                                         10,  #angle
                                        600,  #center_x
                                        350)  #center_y
    
    #Merge the layers and use cuves to adjust color
    splinePoints = [0, 0, 33, 110, 64, 237, 97, 240, 128, 138, 158, 33, 191, 5, 222, 99, 255, 255]    
    copyLayer = pdb.gimp_image_merge_down(img, copyLayer, CLIP_TO_IMAGE)
    textLayer = pdb.gimp_image_get_layer_by_name(img, "Text")
    pdb.gimp_curves_spline(textLayer, HISTOGRAM_VALUE, len(splinePoints), splinePoints) 
    	
    #Make active the bottom layer and done
    pdb.gimp_image_set_active_layer(img, backLayer)
    #Set the defaults
    pdb.gimp_context_set_defaults()
       
register(
    "pm_blinds_text_effect",
    "Creates a sliced text effect",
    "Creates a sliced text effect",
    "Pocholo",
    "Pocholo",
    "2021",
    "Blinds text effect",
    "",
    [
    (PF_TEXT, "customtext", "Text string", 'BLINDS\nTEXT'),
    (PF_FONT, "font", "Font face", "Franklin Gothic Heavy,"),
    (PF_COLOR, "color", "Text color", (255, 0, 255)),
    ],
    [],
    pm_blinds_text_effect, menu="<Image>/Pocholo-scripts/Blinds text effect",
    domain=("gimp20", gimp.locale_directory))
main()							